summaryrefslogtreecommitdiffstats
path: root/kresources/scalix/shared/scalixbase.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kresources/scalix/shared/scalixbase.cpp')
-rw-r--r--kresources/scalix/shared/scalixbase.cpp32
1 files changed, 16 insertions, 16 deletions
diff --git a/kresources/scalix/shared/scalixbase.cpp b/kresources/scalix/shared/scalixbase.cpp
index 0d305c0a..5a23623b 100644
--- a/kresources/scalix/shared/scalixbase.cpp
+++ b/kresources/scalix/shared/scalixbase.cpp
@@ -42,10 +42,10 @@ using namespace Scalix;
ScalixBase::ScalixBase( const TQString& tz )
- : mCreationDate( TQDateTime::currentDateTime() ),
- mLastModified( TQDateTime::currentDateTime() ),
+ : mCreationDate( TQDateTime::tqcurrentDateTime() ),
+ mLastModified( TQDateTime::tqcurrentDateTime() ),
mSensitivity( Public ), mTimeZoneId( tz ),
- mHasPilotSyncId( false ), mHasPilotSyncStatus( false )
+ mHasPilotSyncId( false ), mHasPilotSynctqStatus( false )
{
}
@@ -56,7 +56,7 @@ ScalixBase::~ScalixBase()
void ScalixBase::setFields( const KCal::Incidence* incidence )
{
// So far unhandled KCal::IncidenceBase fields:
// mPilotID, mSyncStatus, mFloats
setUid( incidence->uid() );
setBody( incidence->description() );
@@ -92,7 +92,7 @@ void ScalixBase::setFields( const KABC::Addressee* addressee )
kdDebug(5006) << "Creation time string: " << creationString << endl;
TQDateTime creationDate;
if ( creationString.isEmpty() ) {
- creationDate = TQDateTime::currentDateTime();
+ creationDate = TQDateTime::tqcurrentDateTime();
kdDebug(5006) << "Creation date set to current time\n";
}
else {
@@ -101,7 +101,7 @@ void ScalixBase::setFields( const KABC::Addressee* addressee )
}
TQDateTime modified = addressee->revision();
if ( !modified.isValid() )
- modified = TQDateTime::currentDateTime();
+ modified = TQDateTime::tqcurrentDateTime();
setLastModified( modified );
if ( modified < creationDate ) {
// It's not possible that the modification date is earlier than creation
@@ -231,20 +231,20 @@ unsigned long ScalixBase::pilotSyncId() const
return mPilotSyncId;
}
-void ScalixBase::setPilotSyncStatus( int status )
+void ScalixBase::setPilotSynctqStatus( int status )
{
- mHasPilotSyncStatus = true;
- mPilotSyncStatus = status;
+ mHasPilotSynctqStatus = true;
+ mPilotSynctqStatus = status;
}
-bool ScalixBase::hasPilotSyncStatus() const
+bool ScalixBase::hasPilotSynctqStatus() const
{
- return mHasPilotSyncStatus;
+ return mHasPilotSynctqStatus;
}
-int ScalixBase::pilotSyncStatus() const
+int ScalixBase::pilotSynctqStatus() const
{
- return mPilotSyncStatus;
+ return mPilotSynctqStatus;
}
bool ScalixBase::loadEmailAttribute( TQDomElement& element, Email& email )
@@ -300,7 +300,7 @@ bool ScalixBase::loadAttribute( TQDomElement& element )
else if ( tagName == "pilot-sync-id" )
setPilotSyncId( element.text().toULong() );
else if ( tagName == "pilot-sync-status" )
- setPilotSyncStatus( element.text().toInt() );
+ setPilotSynctqStatus( element.text().toInt() );
else
return false;
@@ -320,8 +320,8 @@ bool ScalixBase::saveAttributes( TQDomElement& element ) const
writeString( element, "sensitivity", sensitivityToString( sensitivity() ) );
if ( hasPilotSyncId() )
writeString( element, "pilot-sync-id", TQString::number( pilotSyncId() ) );
- if ( hasPilotSyncStatus() )
- writeString( element, "pilot-sync-status", TQString::number( pilotSyncStatus() ) );
+ if ( hasPilotSynctqStatus() )
+ writeString( element, "pilot-sync-status", TQString::number( pilotSynctqStatus() ) );
return true;
}
@@ -56,7 +56,7 @@ ScalixBase::~ScalixBase()
{
// So far unhandled KCal::IncidenceBase fields:
- // mPilotID, mSyncStatus, mFloats
+ // mPilotID, mSynctqStatus, mFloats
setUid( incidence->uid() );
setBody( incidence->description() );